==============
Initialization
==============

Papers
------

* [12.11] `On the difficulty of training Recurrent Neural Networks <https://arxiv.org/abs/1211.5063>`_
* [13.12] `Exact solutions to the nonlinear dynamics of learning in deep linear neural networks <https://arxiv.org/abs/1312.6120>`_ (Orthogonal Initialization)
* [15.11] `All you need is a good init <https://arxiv.org/abs/1511.06422>`_
* [15.11] `Data-dependent Initializations of Convolutional Neural Networks <https://arxiv.org/abs/1511.06856>`_
* [15.11] `Unitary Evolution Recurrent Neural Networks <https://arxiv.org/abs/1511.06464>`_
* [15.11] `Regularizing RNNs by Stabilizing Activations <https://arxiv.org/abs/1511.08400>`_
* [16.02] `Orthogonal RNNs and Long-Memory Tasks <https://arxiv.org/abs/1602.06662>`_
* [16.02] `Strongly-Typed Recurrent Neural Networks <https://arxiv.org/abs/1602.02218>`_
